@@ -31,16 +31,22 @@
 
 #include <string.h>
 
+struct _GODocPrivate {
+	GHashTable	*imagebuf; /* used when loading/saving images */
+
+	/* color maps */
+	GSList	*resourcesbuf; /* used when loading/saving color maps and themes */
+};
+
 /**
  * _GODoc:
  * @base: parent object.
  * @uri: URI.
  * @meta_data: metadata.
  * @modified: whether the document has been modified.
- * @first_modification_time: date of the firs modification.
+ * @first_modification_time: date of the first modification.
  * @pristine: whether the document is unchanged since it was created.
  * @images: images used inside the document.
- * @imagebuf: used when loading/saving images.
 **/
 
 enum {
@@ -129,6 +135,8 @@ go_doc_finalize (GObject *obj)
 	if (doc->images)
 		g_hash_table_destroy (doc->images);
 	doc->images = NULL;
+	g_free (doc->priv);
+	doc->priv = NULL;
 
 	go_doc_parent_class->finalize (obj);
 }
@@ -142,6 +150,7 @@ go_doc_init (GODoc *obj)
 	doc->uri	 = NULL;
 	doc->modified	 = FALSE;
 	doc->pristine	 = TRUE;
+	doc->priv = g_new0 (struct _GODocPrivate, 1);
 }
 
 static void
@@ -467,9 +476,9 @@ void
 go_doc_init_write (GODoc *doc, GsfXMLOut *output)
 {
 	g_return_if_fail (GO_IS_DOC (doc));
-	g_return_if_fail (doc->imagebuf == NULL);
+	g_return_if_fail (doc->priv->imagebuf == NULL);
 
-	doc->imagebuf = g_hash_table_new_full (g_str_hash, g_str_equal,
+	doc->priv->imagebuf = g_hash_table_new_full (g_str_hash, g_str_equal,
 					       g_free, NULL);
 	g_object_set_data (G_OBJECT (gsf_xml_out_get_output (output)),
 			   "document", doc);
@@ -479,9 +488,9 @@ void
 go_doc_init_read (GODoc *doc, GsfInput *input)
 {
 	g_return_if_fail (GO_IS_DOC (doc));
-	g_return_if_fail (doc->imagebuf == NULL);
+	g_return_if_fail (doc->priv->imagebuf == NULL);
 
-	doc->imagebuf = g_hash_table_new_full (g_str_hash, g_str_equal,
+	doc->priv->imagebuf = g_hash_table_new_full (g_str_hash, g_str_equal,
 					       g_free, g_object_unref);
 	g_object_set_data (G_OBJECT (input), "document", doc);
 }
@@ -495,24 +504,41 @@ save_image_cb (gpointer key, gpointer img_, gpointer user)
 void
 go_doc_write (GODoc *doc, GsfXMLOut *output)
 {
-	if (g_hash_table_size (doc->imagebuf) > 0) {
+	GSList *ptr;
+	if (g_hash_table_size (doc->priv->imagebuf) > 0 ||
+	    doc->priv->resourcesbuf != NULL) {
 		gsf_xml_out_start_element (output, "GODoc");
-		g_hash_table_foreach (doc->imagebuf, save_image_cb, output);
+		g_hash_table_foreach (doc->priv->imagebuf, save_image_cb, output);
+		for (ptr = doc->priv->resourcesbuf; ptr; ptr = ptr->next) {
+			gsf_xml_out_start_element (output, G_OBJECT_TYPE_NAME (ptr->data));
+			go_persist_sax_save (GO_PERSIST (ptr->data), output);
+			gsf_xml_out_end_element (output);
+		}
+		g_slist_free (doc->priv->resourcesbuf);
+		doc->priv->resourcesbuf = NULL;
 		gsf_xml_out_end_element (output);
 	}
-	g_hash_table_destroy (doc->imagebuf);
-	doc->imagebuf = NULL;
+	g_hash_table_destroy (doc->priv->imagebuf);
+	doc->priv->imagebuf = NULL;
 }
 
+/**
+ * go_doc_save_image:
+ * @doc: a #GODoc
+ * @id: the Id of the #GOImage to save
+ *
+ * Saves the image with the document. Each image will be saved only
+ * once.
+ **/
 void
 go_doc_save_image (GODoc *doc, char const *id)
 {
 	if (!doc)
 		return;
-	if (!g_hash_table_lookup (doc->imagebuf, id)) {
+	if (!g_hash_table_lookup (doc->priv->imagebuf, id)) {
 		GOImage *image = g_hash_table_lookup (doc->images, id);
 		if (image)
-			g_hash_table_replace (doc->imagebuf,
+			g_hash_table_replace (doc->priv->imagebuf,
 					      g_strdup (id),
 					      image);
 	}
@@ -529,7 +555,7 @@ load_image (GsfXMLIn *xin, xmlChar const **attrs)
 		return;
 	for (attr = attrs; *attr; attr += 2)
 		if (!strcmp (*attr, "name"))
-			image = (GOImage *) g_hash_table_lookup (doc->imagebuf, attr[1]);
+			image = (GOImage *) g_hash_table_lookup (doc->priv->imagebuf, attr[1]);
 		else if (!strcmp (*attr, "type"))
 			type = g_type_from_name (attr[1]);
 	if (!image) /* this should not occur, but if it does, we might want to load the image? */
@@ -547,7 +573,7 @@ load_image_data (GsfXMLIn *xin, GsfXMLBlob *unknown)
 	g_return_if_fail (image != NULL);
 	go_image_load_data (image, xin);
 	real = go_doc_add_image (doc, go_image_get_name (image), image);
-	g_hash_table_remove (doc->imagebuf, (gpointer) go_image_get_name (image));
+	g_hash_table_remove (doc->priv->imagebuf, (gpointer) go_image_get_name (image));
 	/*
 	 * We have an issue if the image already existed and this can
 	 * happen on pasting or if one day, we implement merging two
@@ -567,6 +593,32 @@ load_image_data (GsfXMLIn *xin, GsfXMLBlob *unknown)
 	g_object_set_data (G_OBJECT (doc), "new image", NULL);
 }
 
+static void
+load_color_map (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogAxisColorMap *map = NULL;
+	for (; attrs && *attrs; attrs +=2)
+		if (!strcmp ((char const *) *attrs, "id")) {
+			map = GOG_AXIS_COLOR_MAP (gog_axis_color_map_get_from_id ((char const *) attrs[1]));
+			break;
+		}
+	if (map)
+		go_persist_prep_sax (GO_PERSIST (map), xin, attrs);
+}
+
+static void
+load_theme (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogTheme *theme = NULL;
+	for (; attrs && *attrs; attrs +=2)
+		if (!strcmp ((char const *) *attrs, "id")) {
+			theme = GOG_THEME (gog_theme_registry_lookup ((char const *) attrs[1]));
+			break;
+		}
+	if (theme)
+		go_persist_prep_sax (GO_PERSIST (theme), xin, attrs);
+}
+
 void
 go_doc_read (GODoc *doc, GsfXMLIn *xin, xmlChar const **attrs)
 {
@@ -578,6 +630,14 @@ go_doc_read (GODoc *doc, GsfXMLIn *xin, xmlChar const **attrs)
 					 -1, "GOImage",
 					 GSF_XML_CONTENT,
 					 &load_image, &load_image_data),
+		GSF_XML_IN_NODE 	(DOC, COLOR_MAP,
+					 -1, "GogAxisColorMap",
+					 GSF_XML_NO_CONTENT,
+					 &load_color_map, NULL),
+		GSF_XML_IN_NODE 	(DOC, THEME,
+					 -1, "GogTheme",
+					 GSF_XML_NO_CONTENT,
+					 &load_theme, NULL),
 		GSF_XML_IN_NODE_END
 	};
 	static GsfXMLInDoc *xmldoc = NULL;
@@ -589,8 +649,8 @@ go_doc_read (GODoc *doc, GsfXMLIn *xin, xmlChar const **attrs)
 void
 go_doc_end_read	(GODoc *doc)
 {
-	g_hash_table_destroy (doc->imagebuf);
-	doc->imagebuf = NULL;
+	g_hash_table_destroy (doc->priv->imagebuf);
+	doc->priv->imagebuf = NULL;
 }
 
 /**
@@ -610,14 +670,32 @@ GOImage *
 go_doc_image_fetch (GODoc *doc, char const *id, GType type)
 {
 	GOImage *image;
-	g_return_val_if_fail (doc && doc->imagebuf, NULL);
-	image = g_hash_table_lookup (doc->imagebuf, id);
+	g_return_val_if_fail (doc && doc->priv->imagebuf, NULL);
+	image = g_hash_table_lookup (doc->priv->imagebuf, id);
 	if (!image) {
 		image = g_object_new (type, NULL);
 		go_image_set_name (image, id);
-		g_hash_table_replace (doc->imagebuf,
+		g_hash_table_replace (doc->priv->imagebuf,
 				      g_strdup (go_image_get_name (image)),
 				      image);
 	}
 	return image;
 }
+
+/**
+ * go_doc_save_resource:
+ * @doc: a #GODoc
+ * @gp: the #GOPersist to save
+ *
+ * Saves the resource with the document. Each resource will be saved only
+ * once.
+ **/
+void
+go_doc_save_resource (GODoc *doc, GOPersist const *gp)
+{
+	GSList *ptr;
+	for (ptr = doc->priv->resourcesbuf; ptr; ptr = ptr->next)
+		if (ptr->data == gp) /* already marked for saving */
+			return;
+	doc->priv->resourcesbuf = g_slist_prepend (doc->priv->resourcesbuf, (void *) gp);
+}
