@@ -41,6 +41,43 @@
 
 #include <string.h>
 
+/**
+ * GOPluginServiceFileOpenerCallbacks:
+ * @plugin_func_file_probe: probes the file, may be %NULL.
+ * @plugin_func_file_open: opens and reads the file.
+ **/
+
+/**
+ * GOPluginServiceFileSaverCallbacks:
+ * @plugin_func_file_save: saves the file.
+ **/
+
+/**
+ * GOPluginServiceGeneralCallbacks:
+ * @plugin_func_init: initializes the service.
+ * @plugin_func_cleanup: service cleanup.
+ **/
+
+/**
+ * GOPluginServicePluginLoaderCallbacks:
+ * @plugin_func_get_loader_type: returns a #GType for a function loader.
+ * Used by gnumeric in the Python and Perl plugins.
+ **/
+
+/**
+ * GOPluginServiceClass:
+ * @read_xml: read XML node containing the service description.
+ * @activate: actviates the service.
+ * @deactivate: deactivates the service.
+ * @get_description: gets the service description.
+ **/
+
+/**
+ * GOPluginServiceGObjectLoaderClass:
+ * @plugin_service_class: parent class.
+ * @pending: has service instances by type names.
+ **/
+
 #define CXML2C(s) ((char const *)(s))
 #define CC2XML(s) ((xmlChar const *)(s))
 
@@ -626,7 +663,7 @@ go_plugin_file_opener_probe (GOFileOpener const *fo, GsfInput *input,
 static void
 go_plugin_file_opener_open (GOFileOpener const *fo, gchar const *enc,
 			     GOIOContext *io_context,
-			     gpointer FIXME_FIXME_workbook_view,
+			     GoView *view,
 			     GsfInput *input)
 
 {
@@ -645,7 +682,7 @@ go_plugin_file_opener_open (GOFileOpener const *fo, gchar const *enc,
 	}
 
 	g_return_if_fail (service_file_opener->cbs.plugin_func_file_open != NULL);
-	service_file_opener->cbs.plugin_func_file_open (fo, pfo->service, io_context, FIXME_FIXME_workbook_view, input, enc);
+	service_file_opener->cbs.plugin_func_file_open (fo, pfo->service, io_context, view, input, enc);
 }
 
 static void
@@ -888,7 +925,7 @@ go_plugin_file_saver_init (GOPluginFileSaver *fs)
 
 static void
 go_plugin_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
-			    gconstpointer FIXME_FIXME_workbook_view,
+			    GoView const *view,
 			    GsfOutput *output)
 {
 	GOPluginFileSaver *pfs = GO_PLUGIN_FILE_SAVER (fs);
@@ -908,7 +945,7 @@ go_plugin_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
 	}
 
 	g_return_if_fail (service_file_saver->cbs.plugin_func_file_save != NULL);
-	service_file_saver->cbs.plugin_func_file_save (fs, pfs->service, io_context, FIXME_FIXME_workbook_view, output);
+	service_file_saver->cbs.plugin_func_file_save (fs, pfs->service, io_context, view, output);
 }
 
 static void
@@ -1211,6 +1248,12 @@ go_plugin_service_get_description (GOPluginService *service)
 	return service->saved_description;
 }
 
+/**
+ * go_plugin_service_get_plugin:
+ * @service: #GOPluginService
+ *
+ * Returns: (transfer none): the plugin offering @service
+ **/
 GOPlugin *
 go_plugin_service_get_plugin (GOPluginService *service)
 {
@@ -1219,6 +1262,12 @@ go_plugin_service_get_plugin (GOPluginService *service)
 	return service->plugin;
 }
 
+/**
+ * go_plugin_service_get_cbs:
+ * @service: #GOPluginService
+ *
+ * Returns: (transfer none): the callbacks for the service
+ **/
 gpointer
 go_plugin_service_get_cbs (GOPluginService *service)
 {
@@ -1316,7 +1365,7 @@ go_plugin_services_shutdown (void)
 /**
  * go_plugin_service_define:
  * @type_str:  char const *
- * @ctor: #GOPluginServiceCreate
+ * @ctor: (scope async): #GOPluginServiceCreate
  *
  * Allow the definition of new service types
  **/
