@@ -29,10 +29,71 @@
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
+/**
+ * GODataFlags:
+ * @GO_DATA_CACHE_IS_VALID: data in cache are valid.
+ * @GO_DATA_IS_EDITABLE: data can be edited.
+ * @GO_DATA_SIZE_CACHED: cached sise is valid.
+ **/
+
+/**
+ * GODataClass:
+ * @base: base class.
+ * @dup: duplicates the #GOData.
+ * @eq: tests if the data are equal.
+ * @preferred_fmt: gets the preferred format.
+ * @date_conv: gets the #GODateConventions.
+ * @serialize: serializes.
+ * @unserialize: unserializes.
+ * @emit_changed: signals the data have changed.
+ * @get_n_dimensions: gets the dimensions number.
+ * @get_sizes: gets the sizes.
+ * @get_values: gets the values.
+ * @get_bounds: gets the bounds.
+ * @get_value: gets a value.
+ * @get_string: gets a string.
+ * @get_markup: gets the #PangoAttrList* for the string.
+ * @is_valid: checks if the data are valid.
+ **/
+
+/**
+ * GODataScalarClass:
+ * @base:  base class.
+ * @get_value: gets the value.
+ * @get_str: gets the string.
+ * @get_markup: gets the #PangoAttrList* for the string.
+ **/
+
+/**
+ * GODataVectorClass:
+ * @base: base class.
+ * @load_len: loads the vector length.
+ * @load_values: loads the values in the cache.
+ * @get_value: gets a value.
+ * @get_str: gets a string.
+ * @get_markup: gets the #PangoAttrList* for the string.
+ **/
+
+/**
+ * GODataMatrixClass:
+ * @base: base class.
+ * @load_size: loads the matrix length.
+ * @load_values: loads the values in the cache.
+ * @get_value: gets a value.
+ * @get_str: gets a string.
+ * @get_markup: gets the #PangoAttrList* for the string.
+ **/
+
 #define GO_DATA_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), GO_TYPE_DATA, GODataClass))
 #define GO_IS_DATA_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GO_TYPE_DATA))
 #define GO_DATA_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GO_TYPE_DATA, GODataClass))
 
+/**
+ * GODataMatrixSize:
+ * @rows: rows number, negative if dirty, includes missing values.
+ * @columns: columns number, negative if dirty, includes missing values.
+ **/
+
 enum {
 	CHANGED,
 	LAST_SIGNAL
@@ -95,10 +156,10 @@ GSF_CLASS_ABSTRACT (GOData, go_data,
 		    G_TYPE_OBJECT)
 
 /**
- * go_data_dup :
- * @src : #GOData
+ * go_data_dup:
+ * @src: #GOData
  *
- * Returns: A deep copy of @src.
+ * Returns: (transfer full): A deep copy of @src.
  **/
 GOData *
 go_data_dup (GOData const *src)
@@ -928,6 +989,12 @@ GSF_CLASS_ABSTRACT (GODataMatrix, go_data_matrix,
 		    go_data_matrix_class_init, NULL,
 		    GO_TYPE_DATA)
 
+/**
+ * go_data_matrix_get_size: (skip)
+ * @mat: #GODataMatrix
+ *
+ * Returns: the matrix size
+ **/
 GODataMatrixSize
 go_data_matrix_get_size (GODataMatrix *mat)
 {
@@ -947,6 +1014,42 @@ go_data_matrix_get_size (GODataMatrix *mat)
 	return mat->size;
 }
 
+int
+go_data_matrix_get_rows (GODataMatrix *mat)
+{
+	if (!mat)
+		return 0;
+	if (! (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED)) {
+		GODataMatrixClass const *klass = GO_DATA_MATRIX_GET_CLASS (mat);
+
+		g_return_val_if_fail (klass != NULL, 0);
+
+		(*klass->load_size) (mat);
+
+		g_return_val_if_fail (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED, 0);
+	}
+
+	return mat->size.rows;
+}
+
+int
+go_data_matrix_get_columns (GODataMatrix *mat)
+{
+	if (!mat)
+		return 0;
+	if (! (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED)) {
+		GODataMatrixClass const *klass = GO_DATA_MATRIX_GET_CLASS (mat);
+
+		g_return_val_if_fail (klass != NULL, 0);
+
+		(*klass->load_size) (mat);
+
+		g_return_val_if_fail (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED, 0);
+	}
+
+	return mat->size.columns;
+}
+
 double *
 go_data_matrix_get_values (GODataMatrix *mat)
 {
