@@ -36,6 +36,22 @@
  * @GOG_ERROR_BAR_TYPE_PERCENT: Relative errors as percent.
  **/
 
+/**
+ * GogErrorBarDirection:
+ * @GOG_ERROR_BAR_DIRECTION_HORIZONTAL: horizontal (xy plots).
+ * @GOG_ERROR_BAR_DIRECTION_VERTICAL: vertical (xy plots).
+ * @GOG_ERROR_BAR_DIRECTION_ANGULAR: angular (polar plots).
+ * @GOG_ERROR_BAR_DIRECTION_RADIAL: radial (polar plots).
+ **/
+
+/**
+ * GogErrorBarDisplay:
+ * @GOG_ERROR_BAR_DISPLAY_NONE: no display.
+ * @GOG_ERROR_BAR_DISPLAY_POSITIVE: display positive deviations.
+ * @GOG_ERROR_BAR_DISPLAY_NEGATIVE: display negative deviations.
+ * @GOG_ERROR_BAR_DISPLAY_BOTH: display both positive and negative deviations.
+ **/
+
 typedef GObjectClass GogErrorBarClass;
 static GObjectClass *error_bar_parent_klass;
 
@@ -204,6 +220,16 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 	gog_object_request_update (GOG_OBJECT (editor->series));
 }
 
+/**
+ * gog_error_bar_prefs:
+ * @series: #GogSeries
+ * @property: the name of the @series property correspondig to the #GogErrorBar.
+ * @direction: #GogErrorBarDirection
+ * @dalloc: #GogDataAllocator
+ * @cc: #GOCmdContext
+ *
+ * Returns: (transfer full): the error bar properties #GtkWidget
+ **/
 gpointer
 gog_error_bar_prefs (GogSeries *series,
 		     char const *property,
@@ -242,7 +268,7 @@ gog_error_bar_prefs (GogSeries *series,
 	}
 	set = GOG_DATASET (series);
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-error-bar-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-error-bar-prefs.ui", GETTEXT_PACKAGE, cc);
 
 	/* Style properties */
 
@@ -263,7 +289,7 @@ gog_error_bar_prefs (GogSeries *series,
 	style_table = GTK_TABLE (gtk_builder_get_object (gui, "style_table"));
 
 	/* Color */
-	w = go_color_selector_new (editor->color, GO_COLOR_BLACK, "error-bar");
+	w = go_selector_new_color (editor->color, GO_COLOR_BLACK, "error-bar");
 	gtk_label_set_mnemonic_widget (
 		GTK_LABEL (gtk_builder_get_object (gui, "color_label")), w);
 	g_signal_connect (G_OBJECT (w),
@@ -285,7 +311,7 @@ gog_error_bar_prefs (GogSeries *series,
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), cell, "text", 1, NULL);
 
 	for (i = 0; i < G_N_ELEMENTS (display_combo_desc); i++) {
-		pixbuf = go_gdk_pixbuf_new_from_file (direction == GOG_ERROR_BAR_DIRECTION_HORIZONTAL ?
+		pixbuf = go_gdk_pixbuf_load_from_file (direction == GOG_ERROR_BAR_DIRECTION_HORIZONTAL ?
 						  display_combo_desc[i].h_pixbuf :
 						  display_combo_desc[i].v_pixbuf);
 		gtk_list_store_append (list, &iter);
@@ -562,6 +588,12 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 	}
 }
 
+/**
+ * gog_error_bar_dup:
+ * @bar: #GogErrorBar
+ *
+ * Returns: (transfer full): the duplicated error bar.
+ **/
 GogErrorBar  *
 gog_error_bar_dup		(GogErrorBar const *bar)
 {
