@@ -206,7 +206,7 @@ gog_graph_get_property (GObject *obj, guint param_id,
 		g_value_set_object (value, graph->theme);
 		break;
 	case GRAPH_PROP_THEME_NAME :
-		g_value_set_string (value, gog_theme_get_name (graph->theme));
+		g_value_set_string (value, gog_theme_get_id (graph->theme));
 		break;
 	case GRAPH_PROP_WIDTH:
 		g_value_set_double (value, graph->width);
@@ -259,6 +259,7 @@ static void
 cb_theme_changed (GtkComboBox *combo, GogGraph *graph)
 {
 	GtkTreeIter iter;
+	GtkWidget *w = g_object_get_data (G_OBJECT (combo), "save-button");
 
 	if (gtk_combo_box_get_active_iter (combo, &iter)) {
 		GtkTreeModel *model = GTK_TREE_MODEL (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)));
@@ -269,6 +270,7 @@ cb_theme_changed (GtkComboBox *combo, GogGraph *graph)
 			g_object_unref (theme);
 		}
 	}
+	gtk_widget_set_visible (w, graph->theme && gog_theme_get_resource_type (graph->theme) == GO_RESOURCE_EXTERNAL);
 }
 
 static void
@@ -289,6 +291,13 @@ unset_model (GtkComboBox *cb)
 	gtk_combo_box_set_model (cb, NULL);
 }
 
+static void
+save_theme_cb (GtkWidget *w, GogGraph *graph)
+{
+	gog_theme_save_to_home_dir (graph->theme);
+	gtk_widget_hide (w);
+}
+
 static void
 gog_graph_populate_editor (GogObject *gobj,
 			   GOEditor *editor,
@@ -318,7 +327,7 @@ gog_graph_populate_editor (GogObject *gobj,
 		char const *graph_theme_name;
 		int count, index = 0;
 
-		graph_theme_name = gog_theme_get_name (graph->theme);
+		graph_theme_name = gog_theme_get_id (graph->theme);
 		combo = go_gtk_builder_get_widget (gui, "theme_combo");
 		model = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)));
 
@@ -326,11 +335,14 @@ gog_graph_populate_editor (GogObject *gobj,
 				  G_CALLBACK (unset_model), NULL);
 
 		count = 0;
+		box = go_gtk_builder_get_widget (gui, "save-theme");
+		g_signal_connect (G_OBJECT (box), "clicked", G_CALLBACK (save_theme_cb), graph);
+		g_object_set_data (G_OBJECT (combo), "save-button", box);
 		for (ptr = theme_names; ptr != NULL; ptr = ptr->next) {
 			theme = gog_theme_registry_lookup (ptr->data);
 			gtk_list_store_append (model, &iter);
 			gtk_list_store_set (model, &iter,
-			                    0, gog_theme_get_local_name (theme),
+			                    0, gog_theme_get_name (theme),
 			                    1, theme,
 			                    -1);
 			if (strcmp (ptr->data, graph_theme_name) == 0)
@@ -338,12 +350,13 @@ gog_graph_populate_editor (GogObject *gobj,
 			count++;
 		}
 		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), index);
+		gtk_widget_set_visible (box, graph->theme && gog_theme_get_resource_type (graph->theme) == GO_RESOURCE_EXTERNAL);
 
 		g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (cb_theme_changed), graph);
-		g_signal_connect (gtk_builder_get_object (gui, "force_theme_button"), "clicked",
+		g_signal_connect (gtk_builder_get_object (gui, "force-theme-button"), "clicked",
 				  G_CALLBACK (cb_force_theme), graph);
 
-		box = go_gtk_builder_get_widget (gui, "gog_graph_prefs");
+		box = go_gtk_builder_get_widget (gui, "gog-graph-prefs");
 		go_editor_add_page (editor, box, _("Theme"));
 
 		g_slist_free (theme_names);
@@ -517,9 +530,31 @@ gog_graph_init (GogGraph *graph)
 	graph->data_refs = g_hash_table_new (g_direct_hash, g_direct_equal);
 }
 
-GSF_CLASS (GogGraph, gog_graph,
-	   gog_graph_class_init, gog_graph_init,
-	   GOG_TYPE_OUTLINED_OBJECT)
+static void
+gog_graph_sax_save (GOPersist const *gp, GsfXMLOut *output)
+{
+	GogGraph *graph = GOG_GRAPH (gp);
+	if (gog_theme_get_resource_type (graph->theme) != GO_RESOURCE_NATIVE)
+		go_doc_save_resource (graph->doc, GO_PERSIST (graph->theme));
+}
+
+static void
+gog_graph_prep_sax (GOPersist *gp, GsfXMLIn *xin, xmlChar const **attrs)
+{
+	/* nothing to do */
+}
+
+static void
+gog_graph_persist_init (GOPersistClass *iface)
+{
+	iface->prep_sax = gog_graph_prep_sax;
+	iface->sax_save = gog_graph_sax_save;
+}
+
+GSF_CLASS_FULL (GogGraph, gog_graph,
+                NULL, NULL, gog_graph_class_init, NULL,
+                gog_graph_init, GOG_TYPE_OUTLINED_OBJECT, 0,
+                GSF_INTERFACE (gog_graph_persist_init, GO_TYPE_PERSIST))
 
 /**
  * gog_graph_validate_chart_layout:
@@ -630,9 +665,7 @@ gog_graph_num_rows (GogGraph const *graph)
 GogGraph *
 gog_graph_dup (GogGraph const *graph)
 {
-	GogObject *res = gog_object_dup (GOG_OBJECT (graph), NULL, NULL);
-	GOG_GRAPH (res)->doc = graph->doc;
-	return GOG_GRAPH (res);
+	return GOG_GRAPH (gog_object_dup (GOG_OBJECT (graph), NULL, NULL));
 }
 
 /**
@@ -671,6 +704,15 @@ apply_theme (GogObject *object, GogTheme const *theme, gboolean force_auto)
 	}
 }
 
+static gboolean
+theme_loaded_cb (GogGraph *graph)
+{
+	if (gog_theme_get_name (graph->theme) == NULL)
+		return TRUE;
+	apply_theme (GOG_OBJECT (graph), graph->theme, FALSE);
+	return FALSE;
+}
+
 void
 gog_graph_set_theme (GogGraph *graph, GogTheme *theme)
 {
@@ -679,7 +721,10 @@ gog_graph_set_theme (GogGraph *graph, GogTheme *theme)
 
 	graph->theme = theme;
 
-	apply_theme (GOG_OBJECT (graph), graph->theme, FALSE);
+	if (gog_theme_get_name (theme) == NULL) /* the theme is not loaded yet */
+		g_timeout_add (10, (GSourceFunc) theme_loaded_cb, graph);
+	else
+		apply_theme (GOG_OBJECT (graph), graph->theme, FALSE);
 }
 
 /**
@@ -1289,3 +1334,17 @@ void gog_graph_render_to_cairo (GogGraph *graph, cairo_t *cairo, double w, doubl
 	gog_renderer_render_to_cairo (renderer, cairo, w, h);
 	g_object_unref (renderer);
 }
+
+/**
+ * gog_graph_get_document:
+ * @graph: a #GogGraph
+ *
+ * Retrieves the #GODoc for @graph.
+ * Returns: (transfer none): the document.
+ **/
+GODoc *
+gog_graph_get_document (GogGraph *graph)
+{
+	g_return_val_if_fail (GOG_IS_GRAPH (graph), NULL);
+	return graph->doc;
+}
