@@ -34,6 +34,13 @@
 
 #include <gsf/gsf-impl-utils.h>
 
+/**
+ * GOComboBoxClass:
+ * @set_title: sets the title.
+ * @pop_down_done: invoked when the popup has been hidden, if the signal
+ * returns %TRUE, it means it should be killed
+ **/
+
 enum {
 	POP_DOWN_DONE,
 	LAST_SIGNAL
@@ -644,12 +651,10 @@ static gboolean
 cb_tearable_button_release (GtkWidget *w, GdkEventButton *event,
 			    GOComboBox *combo)
 {
-	GtkTearoffMenuItem *tearable;
 
 	g_return_val_if_fail (w != NULL, FALSE);
 	g_return_val_if_fail (GTK_IS_TEAROFF_MENU_ITEM (w), FALSE);
 
-	tearable = GTK_TEAROFF_MENU_ITEM (w);
 	/* FIXME: should we notify the parent menu? */
 
 	if (!combo->priv->torn_off) {
