@@ -26,10 +26,21 @@
 
 #include <gsf/gsf-impl-utils.h>
 
+/**
+ * GOGraphWidgetSizeMode:
+ * @GO_GRAPH_WIDGET_SIZE_MODE_FIT: fits the allocated size, conserving the aspect
+ * ratio.
+ * @GO_GRAPH_WIDGET_SIZE_MODE_FIT_WIDTH: fits the width, conserving the aspect
+ * ratio.
+ * @GO_GRAPH_WIDGET_SIZE_MODE_FIT_HEIGHT: fits the width, conserving the aspect
+ * ratio.
+ * @GO_GRAPH_WIDGET_SIZE_MODE_FIXED_SIZE: use original size.
+ **/
+
 static void go_graph_widget_request_update (GOGraphWidget *w);
 
 /**
- * SECTION: go_graph_widget
+ * SECTION: go-graph-widget
  * @short_description: Widget showing a #GogGraph.
  *
  * Utility widget for showing a #GogGraph.
@@ -156,10 +167,11 @@ go_graph_widget_button_press_event (GtkWidget *widget,
 	if (event->type == GDK_BUTTON_PRESS) {
 		gw->button_pressed = TRUE;
 
-		gdk_window_get_pointer (gtk_widget_get_window (widget),
-					&gw->button_press_x,
-					&gw->button_press_y,
-					NULL);
+		gdk_window_get_device_position (gtk_widget_get_window (widget),
+		                                event->device,
+		                                &gw->button_press_x,
+		                                &gw->button_press_y,
+		                                NULL);
 	}
 
 	if (GTK_WIDGET_CLASS (graph_parent_klass)->button_press_event != NULL) {
@@ -198,8 +210,8 @@ go_graph_widget_motion_notify_event (GtkWidget *widget,
 		GtkAdjustment *hadjustment, *vadjustment;
 		hadjustment = gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (gw));
 		vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (gw));
-		gdk_window_get_pointer (gtk_widget_get_window (widget),
-					&x, &y, NULL);
+		gdk_window_get_device_position (gtk_widget_get_window (widget),
+		                                 event->device, &x, &y, NULL);
 
 		if (hadjustment != NULL) {
 			newval = gtk_adjustment_get_value (hadjustment) - (x - gw->button_press_x);
@@ -461,8 +473,8 @@ GSF_CLASS (GOGraphWidget, go_graph_widget,
 	   gtk_layout_get_type ())
 
 /**
- * go_graph_widget_get_graph :
- * @widget : #GOGraphWidget
+ * go_graph_widget_get_graph:
+ * @widget: #GOGraphWidget
  *
  * Returns: (transfer none): the #GogGraph embedded in the widget.
  **/
@@ -474,8 +486,8 @@ go_graph_widget_get_graph (GOGraphWidget *widget)
 }
 
 /**
- * go_graph_widget_get_chart :
- * @widget : #GOGraphWidget
+ * go_graph_widget_get_chart:
+ * @widget: #GOGraphWidget
  *
  * Returns: (transfer none): the #GogChart created by go_graph_widget_new().
  **/
@@ -488,8 +500,8 @@ go_graph_widget_get_chart (GOGraphWidget *widget)
 }
 
 /**
- * go_graph_widget_get_renderer :
- * @widget : #GOGraphWidget
+ * go_graph_widget_get_renderer:
+ * @widget: #GOGraphWidget
  *
  * Returns: (transfer none): the #GogRenderer used by the widget.
  **/
