@@ -212,10 +212,10 @@ static LocaleInfo locale_trans_array[] = {
 	{N_("Netherlands/Frisian (fy_NL)"),              "fy_NL", LG_WESTERN_EUROPE },
 	{N_("Ireland/Gaelic (ga_IE)"),                   "ga_IE", LG_WESTERN_EUROPE },
 	{N_("Great Britain/Scottish Gaelic (gd_GB)"),    "gd_GB", LG_WESTERN_EUROPE },
-	{N_("Eritrea/Ge'ez “gez_ER)"),                   "gez_ER", LG_AFRICA },
-	{N_("Ethiopia/Ge'ez “gez_ET)"),                  "gez_ET", LG_AFRICA },
+	{N_("Eritrea/Ge'ez (gez_ER)"),                   "gez_ER", LG_AFRICA },
+	{N_("Ethiopia/Ge'ez (gez_ET)"),                  "gez_ET", LG_AFRICA },
 	{N_("Spain/Galician (gl_ES)"),                   "gl_ES", LG_WESTERN_EUROPE },
-	{N_("India/Gurajati “gu_IN)"),                   "gu_IN", LG_ASIA },
+	{N_("India/Gujarati (gu_IN)"),                   "gu_IN", LG_ASIA },
 	{N_("Great Britain/Manx Gaelic (gv_GB)"),        "gv_GB", LG_WESTERN_EUROPE },
 	{N_("Nigeria/Hausa (ha_NG)"),                    "ha_NG", LG_AFRICA },
 	{N_("Israel/Hebrew (he_IL)"),                    "he_IL", LG_MIDDLE_EAST },
@@ -339,7 +339,7 @@ static LocaleInfo locale_trans_array[] = {
 	{N_("Vietnam (vi_VN)"),                          "vi_VN", LG_ASIA },
 	{N_("Belgium/Walloon (wa_BE)"),                  "wa_BE", LG_WESTERN_EUROPE },
 	{N_("Switzerland/Walser (wae_CH)"),              "wae_CH", LG_WESTERN_EUROPE },
-	{N_("Ethiopia/Walaita (wal_ET)"),                "wal_ET", LG_AFRICA },
+	{N_("Ethiopia/Wollayta (wal_ET)"),                "wal_ET", LG_AFRICA },
 	{N_("Senegal/Wolof (wo_SN)"),                    "wo_SN", LG_AFRICA },
 	{N_("South Africa/Xhosa (xh_ZA)"),               "xh_ZA", LG_AFRICA },
 	{N_("United States/Yiddish (yi_US)"),            "yi_US", LG_NORTH_AMERICA },
