@@ -98,13 +98,32 @@ SUFFIX(go_quad_functional) (void)
 #endif
 }
 
+static guint SUFFIX(go_quad_depth) = 0;
+
 static DOUBLE SUFFIX(CST);
 
+/**
+ * go_quad_start: (skip)
+ *
+ * Initializes #GOQuad arythmetics. Any use of #GOQuad must occur between calls
+ * to go_quad_start() and go_quad_end().
+ * Returns: (transfer full): a pointer to pass to go_quad_end() when done.
+ **/
+/**
+ * go_quad_startl: (skip)
+ *
+ * Initializes #GOQuadl arythmetics. Any use of #GOQuadl must occur between calls
+ * to go_quad_startl() and go_quad_endl().
+ * Returns: (transfer full): a pointer to pass to go_quad_endl() when done.
+ **/
 void *
 SUFFIX(go_quad_start) (void)
 {
 	void *res = NULL;
 
+	if (SUFFIX(go_quad_depth)++ > 0)
+		return NULL;
+
 	if (!SUFFIX(go_quad_functional) ())
 		g_warning ("quad precision math may not be completely accurate.");
 
@@ -130,9 +149,16 @@ SUFFIX(go_quad_start) (void)
 	return res;
 }
 
+/**
+ * go_quad_end: (skip)
+ **/
+/**
+ * go_quad_endl: (skip)
+ **/
 void
 SUFFIX(go_quad_end) (void *state)
 {
+	SUFFIX(go_quad_depth)--;
 	if (!state)
 		return;
 
@@ -145,6 +171,12 @@ SUFFIX(go_quad_end) (void *state)
 	g_free (state);
 }
 
+/**
+ * go_quad_init: (skip)
+ **/
+/**
+ * go_quad_initl: (skip)
+ **/
 void
 SUFFIX(go_quad_init) (QUAD *res, DOUBLE h)
 {
@@ -152,12 +184,24 @@ SUFFIX(go_quad_init) (QUAD *res, DOUBLE h)
 	res->l = 0;
 }
 
+/**
+ * go_quad_value: (skip)
+ **/
+/**
+ * go_quad_valuel: (skip)
+ **/
 DOUBLE
 SUFFIX(go_quad_value) (const QUAD *a)
 {
 	return a->h + a->l;
 }
 
+/**
+ * go_quad_add: (skip)
+ **/
+/**
+ * go_quad_addl: (skip)
+ **/
 void
 SUFFIX(go_quad_add) (QUAD *res, const QUAD *a, const QUAD *b)
 {
@@ -167,8 +211,16 @@ SUFFIX(go_quad_add) (QUAD *res, const QUAD *a, const QUAD *b)
 		: b->h - r + a->h + a->l + b->l;
 	res->h = r + s;
 	res->l = r - res->h + s;
+
+	g_return_if_fail (SUFFIX(go_quad_depth) > 0);
 }
 
+/**
+ * go_quad_sub: (skip)
+ **/
+/**
+ * go_quad_subl: (skip)
+ **/
 void
 SUFFIX(go_quad_sub) (QUAD *res, const QUAD *a, const QUAD *b)
 {
@@ -180,6 +232,12 @@ SUFFIX(go_quad_sub) (QUAD *res, const QUAD *a, const QUAD *b)
 	res->l = r - res->h + s;
 }
 
+/**
+ * go_quad_mul12: (skip)
+ **/
+/**
+ * go_quad_mul12l: (skip)
+ **/
 void
 SUFFIX(go_quad_mul12) (QUAD *res, DOUBLE x, DOUBLE y)
 {
@@ -197,6 +255,12 @@ SUFFIX(go_quad_mul12) (QUAD *res, DOUBLE x, DOUBLE y)
 	res->l = p - res->h + q + tx * ty;
 }
 
+/**
+ * go_quad_mul: (skip)
+ **/
+/**
+ * go_quad_mull: (skip)
+ **/
 void
 SUFFIX(go_quad_mul) (QUAD *res, const QUAD *a, const QUAD *b)
 {
@@ -207,6 +271,12 @@ SUFFIX(go_quad_mul) (QUAD *res, const QUAD *a, const QUAD *b)
 	res->l = c.h - res->h + c.l;
 }
 
+/**
+ * go_quad_div: (skip)
+ **/
+/**
+ * go_quad_divl: (skip)
+ **/
 void
 SUFFIX(go_quad_div) (QUAD *res, const QUAD *a, const QUAD *b)
 {
@@ -218,6 +288,12 @@ SUFFIX(go_quad_div) (QUAD *res, const QUAD *a, const QUAD *b)
 	res->l = c.h - res->h + c.l;
 }
 
+/**
+ * go_quad_sqrt: (skip)
+ **/
+/**
+ * go_quad_sqrtl: (skip)
+ **/
 void
 SUFFIX(go_quad_sqrt) (QUAD *res, const QUAD *a)
 {
@@ -232,6 +308,12 @@ SUFFIX(go_quad_sqrt) (QUAD *res, const QUAD *a)
 		res->h = res->l = 0;
 }
 
+/**
+ * go_quad_dot_product: (skip)
+ **/
+/**
+ * go_quad_dot_productl: (skip)
+ **/
 void
 SUFFIX(go_quad_dot_product) (QUAD *res, const QUAD *a, const QUAD *b, int n)
 {
