@@ -35,7 +35,9 @@ struct _GOEditor {
 	unsigned	*store_page;		/* pointer to a place for storing last edited page */
 	GSList		*pages;			/* GOEditorPage */
 	GData		*registered_widgets;
+	unsigned     ref_count;
 };
+GType go_editor_get_type (void);
 
 GOEditor	*go_editor_new 		  (void);
 void 		 go_editor_free 		  (GOEditor *editor);
