@@ -49,6 +49,26 @@
 #endif
 #include <time.h>
 
+/**
+ * GOFilePermissions:
+ * @owner_read: owner can read.
+ * @owner_write: owner can write.
+ * @owner_execute: owner can execute.
+ * @group_read: group can read.
+ * @group_write: group can write.
+ * @group_execute: group can execute.
+ * @others_read: everybody can read.
+ * @others_write: everybody can write.
+ * @others_execute: everybody can execute.
+ **/
+
+/**
+ * GODotDot:
+ * @GO_DOTDOT_SYNTACTIC: assume no symlinks.
+ * @GO_DOTDOT_TEST: check.
+ * @GO_DOTDOT_LEAVE: leave alone.
+ **/
+
 #ifdef G_OS_WIN32
 typedef HRESULT (WINAPI *FindMimeFromData_t) (LPBC pBC,
 					      LPCWSTR pwzUrl,
@@ -540,7 +560,7 @@ open_plain_file (char const *path, GError **err)
  * @err: #GError
  *
  * Try all available methods to open a file or return an error
- * Returns: non-%NULL on success
+ * Returns: (transfer full): non-%NULL on success
  **/
 GsfInput *
 go_file_open (char const *uri, GError **err)
@@ -578,6 +598,15 @@ go_file_open (char const *uri, GError **err)
 	return gsf_input_gio_new_for_uri (uri, err);
 }
 
+/**
+ * go_file_create:
+ * @uri: target uri
+ * @err: #GError
+ *
+ * Creates a file or return an error. If the file already exists, it is
+ * replaced.
+ * Returns: (transfer full): non-%NULL on success
+ **/
 GsfOutput *
 go_file_create (char const *uri, GError **err)
 {
@@ -610,6 +639,13 @@ go_file_create (char const *uri, GError **err)
 /* ------------------------------------------------------------------------- */
 /* Adapted from gtkfilechooserdefault.c.  Unfortunately it is static there.  */
 
+/**
+ * go_file_split_urls:
+ * @data: a string filled with a list of URIs separated by new lines.
+ *
+ * Splits the chain into a list of URIs. Lines starting with '#' are ignored.
+ * Returns: (element-type char) (transfer full): the URIs list.
+ **/
 GSList *
 go_file_split_urls (char const *data)
 {
@@ -709,12 +745,33 @@ go_file_get_group_name (char const *uri)
 	return (nameutf8 ? g_string_free (nameutf8, FALSE) : NULL);
 }
 
+static GOFilePermissions *
+go_file_permissions_copy (GOFilePermissions *file_permissions)
+{
+	GOFilePermissions *res = g_new (GOFilePermissions, 1);
+	memcpy (res, file_permissions, sizeof(GOFilePermissions));
+	return res;
+}
+
+GType
+go_file_permissions_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GOFilePermissions",
+			 (GBoxedCopyFunc)go_file_permissions_copy,
+			 (GBoxedFreeFunc)g_free);
+	}
+	return t;
+}
+
 GOFilePermissions *
 go_get_file_permissions (char const *uri)
 {
 	GOFilePermissions * file_permissions = NULL;
 
-	/* Try setting unix mode */
+	/* Try getting unix mode */
 	GFile *file = g_file_new_for_uri (uri);
 	GError *error = NULL;
 	GFileInfo *info = g_file_query_info (file,
@@ -724,8 +781,10 @@ go_get_file_permissions (char const *uri)
 		g_error_free (error);
 		error = NULL;
 	   	info = g_file_query_info (file,
-					    	     G_FILE_ATTRIBUTE_ACCESS_CAN_READ","G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE,
-						     G_FILE_QUERY_INFO_NONE, NULL, &error);
+					  G_FILE_ATTRIBUTE_ACCESS_CAN_READ","
+					  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","
+					  G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE,
+					  G_FILE_QUERY_INFO_NONE, NULL, &error);
 		if (error)
 			g_error_free (error);
 		else {
@@ -909,7 +968,7 @@ go_file_get_date_changed (char const *uri)
 
 /**
  * go_url_encode:
- * @uri_fragment: The uri part to be encoded
+ * @uri: The uri part to be encoded
  * @type: 0: mailto, 1: file or http
  *
  * url-encode a string according to RFC 2368.
@@ -1106,6 +1165,14 @@ go_mime_type_get_description (gchar const *mime_type)
 static gchar **saved_args;
 #endif
 
+/**
+ * go_shell_argv_to_glib_encoding:
+ * @argc: arguments number
+ * @argv: command line arguments
+ *
+ * Transform arguments to UTF-8 when needed.
+ * Returns: (transfer none): the arguments in UTF-8 locale.
+ **/
 gchar const **
 go_shell_argv_to_glib_encoding (gint argc, gchar const **argv)
 {
