@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-format.h :
  *
@@ -102,6 +103,7 @@ typedef struct {
 	/* SCIENTIFIC: */
 	int exponent_step;
 	int exponent_digits;
+	gboolean exponent_sign_forced;
 	gboolean use_markup;
 	gboolean simplify_mantissa;
 	gboolean append_SI;
@@ -125,10 +127,9 @@ typedef struct {
 GType go_format_details_get_type (void);
 /*************************************************************************/
 
-/* We need these in the format selector */
-#define ALLOW_EE_MARKUP
-#define ALLOW_SI_APPEND
-#define ALLOW_PI_SLASH
+gboolean go_format_allow_ee_markup (void);
+gboolean go_format_allow_si (void);
+gboolean go_format_allow_pi_slash (void);
 
 /*************************************************************************/
 
