@@ -960,7 +960,7 @@ text_layout_init (StylePrefState *state, guint32 enable, GOEditor *editor, GOCmd
 	if (!enable)
 		return;
 
-	w = go_rotation_sel_new ();
+	w = go_rotation_sel_new_full ();
 	go_rotation_sel_set_rotation (GO_ROTATION_SEL (w),
 		style->text_layout.angle);
 	g_signal_connect (G_OBJECT (w), "rotation-changed",
@@ -1315,7 +1315,7 @@ go_style_init (GOStyle *style)
 	style->line.width = 0;
 	style->line.cap = CAIRO_LINE_CAP_BUTT;
 	style->line.join = CAIRO_LINE_JOIN_MITER;
-	style->line.miter_limit = 10.;
+	style->line.miter_limit = 2.;
 	style->fill.type = GO_STYLE_FILL_NONE;
 	style->fill.gradient.brightness = -1.;
 	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_BLACK);
@@ -1697,7 +1697,7 @@ go_style_persist_prep_sax (GOPersist *gp, GsfXMLIn *xin, xmlChar const **attrs)
 {
 	static GsfXMLInNode const dtd[] = {
 		GSF_XML_IN_NODE 	(STYLE, STYLE,
-					 -1, "GogObject",
+					 -1, "Style",
 					 FALSE, NULL, NULL),
 		GSF_XML_IN_NODE_FULL 	(STYLE, STYLE_LINE,
 					 -1, "line",
@@ -1806,6 +1806,12 @@ go_style_is_fill_visible (const GOStyle *style)
 	return (style->fill.type != GO_STYLE_FILL_NONE);
 }
 
+/**
+ * go_style_force_auto:
+ * @style: a #GOStyle
+ *
+ * Sets all auto fields in @style to %TRUE.
+ **/
 void
 go_style_force_auto (GOStyle *style)
 {
@@ -1819,13 +1825,53 @@ go_style_force_auto (GOStyle *style)
 	style->marker.auto_fill_color =
 	style->line.auto_dash =
 	style->line.auto_color =
+	style->line.auto_fore =
+	style->line.auto_width =
 	style->fill.auto_type =
 	style->fill.auto_fore =
 	style->fill.auto_back =
+	style->fill.auto_pattern =
+	style->fill.gradient.auto_dir =
+	style->fill.gradient.auto_brightness =
 	style->font.auto_scale =
+	style->font.auto_font =
+	style->font.auto_color =
 	style->text_layout.auto_angle = TRUE;
 }
 
+/**
+ * go_style_clear_auto:
+ * @style: a #GOStyle
+ *
+ * Sets all auto fields in @style to %FALSE.
+ **/
+void
+go_style_clear_auto	(GOStyle *style)
+{
+	g_return_if_fail (GO_IS_STYLE (style));
+
+	if (style->marker.mark != NULL)
+		g_object_unref (G_OBJECT (style->marker.mark));
+	style->marker.mark = go_marker_new ();
+	style->marker.auto_shape =
+	style->marker.auto_outline_color =
+	style->marker.auto_fill_color =
+	style->line.auto_dash =
+	style->line.auto_color =
+	style->line.auto_fore =
+	style->line.auto_width =
+	style->fill.auto_type =
+	style->fill.auto_fore =
+	style->fill.auto_back =
+	style->fill.auto_pattern =
+	style->fill.gradient.auto_dir =
+	style->fill.gradient.auto_brightness =
+	style->font.auto_scale =
+	style->font.auto_font =
+	style->font.auto_color =
+	style->text_layout.auto_angle = FALSE;
+}
+
 gboolean
 go_style_is_auto (GOStyle *style)
 {
