@@ -563,6 +563,9 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 	}
 
+	/* clip the plot to it's allocated rectangle, see #684195 */
+	gog_renderer_push_clip_rectangle (view->renderer, area->x, area->y, area->w, area->h);
+
 	x_map = gog_chart_map_get_axis_map (chart_map, 0);
 	y_map = gog_chart_map_get_axis_map (chart_map, 1);
 
@@ -796,6 +799,8 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 		}
 		gog_renderer_pop_style (view->renderer);
 	}
+	gog_renderer_pop_clip (view->renderer);
+
 	/* Now render children */
 	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next)
 		gog_view_render	(ptr->data, bbox);
@@ -987,6 +992,7 @@ gog_histogram_plot_series_update (GogObject *obj)
 			}
 			if (width > 0. && (y || y_)) {
 				double m, M;
+				/* ignore nans */
 				if (y) {
 					m = (y_)? (MIN (y[0], y_[0])): y[0];
 					M = (y_)? (MAX (y[y_len-1], y_[y__len-1])): y[y_len-1];
@@ -994,6 +1000,8 @@ gog_histogram_plot_series_update (GogObject *obj)
 					m = y_[0];
 					M = y_[y__len-1];
 				}
+				if (!go_finite (m) || !go_finite (M))
+					return;
 				/* round m */
 				m = floor ((m - origin)/ width) * width + origin;
 				x_len = ceil ((M - m) / width) + 1;
