@@ -35,12 +35,48 @@
 
 /*****************************************************************************/
 
+enum {
+	XYZ_SURFACE_MISSING_AS_NAN,
+	XYZ_SURFACE_MISSING_AS_ZERO,
+	/* we might add interpolation methods there */
+	XYZ_SURFACE_MISSING_MAX
+};
+
+static struct {unsigned n; char const *name;} missing_as_strings[] =
+{
+	{XYZ_SURFACE_MISSING_AS_NAN, "invalid"},
+	{XYZ_SURFACE_MISSING_AS_ZERO, "0"}
+};
+
+static char const *
+missing_as_string (unsigned n)
+{
+	unsigned i;
+	for (i = 0 ; i < G_N_ELEMENTS (missing_as_strings); i++)
+		if (missing_as_strings[i].n == n)
+			return missing_as_strings[i].name;
+	return "invalid";	/* default property value */
+}
+
+static unsigned
+missing_as_value (char const *name)
+{
+	unsigned i;
+	for (i = 0 ; i < G_N_ELEMENTS (missing_as_strings); i++)
+		if (!strcmp (missing_as_strings[i].name, name))
+			return missing_as_strings[i].n;
+	return 0;	/* default property value */
+}
+
+/*****************************************************************************/
+
 enum {
 	XYZ_SURFACE_PROP_0,
 	XYZ_SURFACE_PROP_ROWS,
 	XYZ_SURFACE_PROP_COLUMNS,
 	XYZ_SURFACE_PROP_AUTO_ROWS,
-	XYZ_SURFACE_PROP_AUTO_COLUMNS
+	XYZ_SURFACE_PROP_AUTO_COLUMNS,
+	XYZ_SURFACE_PROP_MISSING_AS
 };
 
 static GogObjectClass *plot_xyz_contour_parent_klass;
@@ -81,27 +117,41 @@ gog_xyz_surface_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality
 	if (GOG_IS_CONTOUR_PLOT (plot)) {
 		GogXYZContourPlot *xyz = GOG_XYZ_CONTOUR_PLOT (plot);
 		if (xyz->grid[0].data) {
+			if (xyz->base.x_vals)
+				g_object_unref (xyz->base.x_vals);
 			xyz->base.x_vals = g_object_ref (xyz->grid[0].data);
 			xyz->base.columns = go_data_get_vector_size (plot->x_vals);
 		}
 		if (xyz->grid[1].data) {
+			if (xyz->base.y_vals)
+				g_object_unref (xyz->base.y_vals);
 			xyz->base.y_vals = g_object_ref (xyz->grid[1].data);
 			xyz->base.rows = go_data_get_vector_size (plot->y_vals);
 		}
 	} else {
 		GogXYZSurfacePlot *xyz = GOG_XYZ_SURFACE_PLOT (plot);
 		if (xyz->grid[0].data) {
+			if (xyz->base.x_vals)
+				g_object_unref (xyz->base.x_vals);
 			xyz->base.x_vals = g_object_ref (xyz->grid[0].data);
 			xyz->base.columns = go_data_get_vector_size (plot->x_vals);
 		}
 		if (xyz->grid[1].data) {
+			if (xyz->base.y_vals)
+				g_object_unref (xyz->base.y_vals);
 			xyz->base.y_vals = g_object_ref (xyz->grid[1].data);
 			xyz->base.rows = go_data_get_vector_size (plot->y_vals);
 		}
 	}
 	n = plot->rows * plot->columns;
-	if (n == 0)
+	if (plot->rows < 2 || plot->columns < 2) {
+		/* we store the default value to avoid warnings about invalid values */
+		if (plot->rows < 2)
+			((GogXYZPlot *) plot)->rows = 10;
+		if (plot->columns < 2)
+			((GogXYZPlot *) plot)->columns = 10;
 		return NULL;
+	}
 	x_limits = go_range_sort (go_data_get_values (gog_xyz_plot_get_x_vals ((GogXYZPlot *) plot)), plot->columns);
 	for (i = 0; i < plot->columns - 1; i++)
 		x_limits[i] = (x_limits[i] + x_limits[i+1]) / 2.;
@@ -152,6 +202,10 @@ gog_xyz_surface_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality
 	for (k = 0; k < n; ++k)
 		if (grid[k] != 0)
 			data[k] /= grid[k];
+		else if (GOG_IS_CONTOUR_PLOT (plot)?
+		         	GOG_XYZ_CONTOUR_PLOT (plot)->missing_as == XYZ_SURFACE_MISSING_AS_NAN:
+			        GOG_XYZ_SURFACE_PLOT (plot)->missing_as == XYZ_SURFACE_MISSING_AS_NAN)
+			data[k] = go_nan;
 
 	if (GOG_IS_CONTOUR_PLOT (plot)) {
 		GogAxisMap *map;
@@ -162,6 +216,8 @@ gog_xyz_surface_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality
 		unsigned max;
 
 		if (!gog_axis_get_bounds (axis, &minimum, &maximum)) {
+			series->num_elements = 2; /* series name and one slice */
+			*cardinality_changed = TRUE;
 			g_free (grid);
 			g_free (data);
 			return NULL;
@@ -379,6 +435,13 @@ gog_xyz_surface_plot_set_property (GObject *obj, guint param_id,
 			plot->x_vals = NULL;
 		}
 		break;
+	case XYZ_SURFACE_PROP_MISSING_AS:
+		if (GOG_IS_CONTOUR_PLOT (plot))
+			GOG_XYZ_CONTOUR_PLOT (plot)->missing_as = missing_as_value (g_value_get_string (value));
+		else
+			GOG_XYZ_SURFACE_PLOT (plot)->missing_as = missing_as_value (g_value_get_string (value));
+			gog_object_request_update (GOG_OBJECT (plot));
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
@@ -405,6 +468,11 @@ gog_xyz_surface_plot_get_property (GObject *obj, guint param_id,
 	case XYZ_SURFACE_PROP_AUTO_COLUMNS :
 		g_value_set_boolean (value, plot->auto_x);
 		break;
+	case XYZ_SURFACE_PROP_MISSING_AS :
+		g_value_set_string (value, missing_as_string (GOG_IS_CONTOUR_PLOT (plot)?
+		                                              GOG_XYZ_CONTOUR_PLOT (plot)->missing_as:
+			                                          GOG_XYZ_SURFACE_PLOT (plot)->missing_as));
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -438,7 +506,7 @@ common_init_class (GogXYZPlotClass *klass)
 	g_object_class_install_property (gobject_klass, XYZ_SURFACE_PROP_AUTO_ROWS,
 		g_param_spec_boolean ("auto-rows",
 			_("Auto Rows"),
-			_("Whether the rows limts should be evaluated"),
+			_("Whether the rows limits should be evaluated"),
 			TRUE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, XYZ_SURFACE_PROP_COLUMNS,
@@ -450,9 +518,15 @@ common_init_class (GogXYZPlotClass *klass)
 	g_object_class_install_property (gobject_klass, XYZ_SURFACE_PROP_AUTO_COLUMNS,
 		g_param_spec_boolean ("auto-columns",
 			_("Auto Columns"),
-			_("Whether the columns limts should be evaluated"),
+			_("Whether the columns limits should be evaluated"),
 			TRUE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, XYZ_SURFACE_PROP_MISSING_AS,
+		g_param_spec_string ("missing-as",
+			_("Missing as"),
+			_("How to deal with missing data"),
+			"invalid",
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_object_klass->update	= gog_xyz_surface_plot_update;
 
